/*
 * CLIF is a Load Injection Framework
 * Copyright (C) 2005, 2006, 2008 France Telecom
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * CLIF
 *
 * Contact: clif@ow2.org
 */
package org.objectweb.clif.isac.plugins;

import java.util.Hashtable;
import java.util.Map;
import org.objectweb.clif.scenario.isac.exception.IsacRuntimeException;
import org.objectweb.clif.scenario.isac.plugin.ControlAction;
import org.objectweb.clif.scenario.isac.plugin.DataProvider;
import org.objectweb.clif.scenario.isac.plugin.TestAction;
import org.objectweb.clif.scenario.isac.plugin.SessionObjectAction;

/**
 * This plug-in provides <code>true</code> and <code>false</code> constant conditions,
 * as well as printing primitives for stdout and stderr. It also provides a timestamp
 * facility through a variable.
 * 
 * @author Emmanuel Varoquaux
 * @author Bruno Dillenseger
 */
public class Common implements
	SessionObjectAction,
	TestAction,
	DataProvider,
	ControlAction
{
	public static final int PRINTOUT_CTRL = 0;
	public static final int PRINTERR_CTRL = 1;
	public static final int TRUE_TEST = 0;
	public static final int FALSE_TEST = 1;
	public static final String STRING_ARG = "string";
	public static final String DATE_MS_GET = "date_ms";


	//////////////////
	// constructors //
	//////////////////

	public Common()
	{
	}

	public Common(Hashtable params)
	{
		this();
	}

	///////////////////////////////////
	// SessionObjectAction interface //
	///////////////////////////////////

	public Object createNewSessionObject()
	{
		return new Common();
	}

	public void reset() {}

	public void close() {}

	//////////////////////////
	// TestAction interface //
	//////////////////////////

	public boolean doTest(int number, Map params)
	{
		switch (number)
		{
		case TRUE_TEST:
			return true;
		case FALSE_TEST:
			return false;
		default:
			throw new Error("Fatal error in ISAC's Common plug-in: unknown test identifier " + number);
		}
	}

	/////////////////////////////
	// ControlAction interface //
	/////////////////////////////

	public void doControl(int number, Map params)
	{
		switch (number)
		{
			case PRINTOUT_CTRL:
				System.out.println(params.get(STRING_ARG));
				break;
			case PRINTERR_CTRL:
				System.err.println(params.get(STRING_ARG));
				break;
			default:
				throw new Error("Fatal error in ISAC's Common plug-in: unknown control identifier " + number);
		}
	}

	////////////////////////////
	// DataProvider interface //
	////////////////////////////

	public String doGet(String var)
	{
		if (var.equals(DATE_MS_GET))
		{
			return String.valueOf(System.currentTimeMillis());
		}
		else
		{
			throw new IsacRuntimeException("Unknown variable name in Common plug-in: " + var);
		}
	}
}
