/*
 * CLIF is a Load Injection Framework
 * Copyright (C) 2006 F.Barreca & I.Vassilev
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * CLIF
 *
 * Contact: clif@objectweb.org
 */

package org.objectweb.clif.isac.plugins.sipinjector10;

/**
 * This class holds all the constant parameters for the SIP injector
 * 
 * @author Fabien Barreca
 * @author Iassen Vassilev
 */
public class Constants {
	
	// SIP Implementation constants
	public static final String STR_SIP_IMPLEMENTATION = "gov.nist";

	public static final String STR_SIP_FROMNAME = "clif";
	public static final String STR_SIP_FROMADDRESS = "objectweb.org";
	public static final String STR_SIP_FROMDISPLAYNAME = "The clif console";
	public static final String STR_SIP_TODISPLAYNAME = "System under test";
	public static final long DEFAULT_TIMEOUT = 60000;
	public static final String DEFAULT_STR_SERVERPORT = "5060";
	public static final int DEFAULT_MYPORT = 5060;
	public static final String STR_HEADERNAME = "IDHEADER";
	public static final String STR_HEADERCSEQ = "SEQHEADER";
	
	// Object parameters strings - SIP
	public static final String STR_PARAM_TRANSPORTTYPE = "transportType";
	public static final String STR_PARAM_SERVERSIPUSER = "serverSIPUser";
	public static final String STR_PARAM_SERVERSIPDOMAIN = "serverSIPDomain";
	public static final String STR_PARAM_SERVERIPADDRESS = "serverIPAddress";
	public static final String STR_PARAM_MYIPADDRESS = "myIPAddress";
	public static final String STR_PARAM_MYUSERNAME = "myUserName";
	public static final String STR_PARAM_TIMEOUT = "timeOut";
	public static final String STR_TRANSPORTTYPE_UDP = "udp";
	public static final String STR_TRANSPORTTYPE_TCP = "tcp";
	public static final String STR_PARAM_MYLISTENINGPORT = "myListeningPort";
	public static final String STR_PARAM_SERVERLISTENINGPORT = "serverListeningPort";
	
	// Object parameters strings - SDP
	public static final String STR_PARAM_SDP_V = "SDP_v";
	public static final String STR_PARAM_SDP_O = "SDP_o";
	public static final String STR_PARAM_SDP_S = "SDP_s";
	public static final String STR_PARAM_SDP_C = "SDP_c";
	public static final String STR_PARAM_SDP_T = "SDP_t";
	public static final String STR_PARAM_SDP_M = "SDP_m";
	public static final String STR_PARAM_SDP_A1 = "SDP_a1";
	public static final String STR_PARAM_SDP_A2 = "SDP_a2";
	public static final String STR_PARAM_SDP_A3 = "SDP_a3";
	public static final String STR_PARAM_SDP_A4 = "SDP_a4";
	public static final String STR_PARAM_SDP_A5 = "SDP_a5";
	public static final String STR_PARAM_SDP_A6 = "SDP_a6";
	public static final String STR_PARAM_SDP_A7 = "SDP_a7";
	public static final String STR_PARAM_SDP_A8 = "SDP_a8";
	public static final String STR_PARAM_SDP_A9 = "SDP_a9";

	
	// Sample actions constants definition
	public static final int SAMPLE_WAIT = 0;
	public static final int SAMPLE_CANCEL = 2;
	public static final int SAMPLE_BYE = 3;
	
	public static final String STR_SAMPLE_WAIT = "waitResponse";
	public static final String STR_SAMPLE_CANCEL = "cancel";
	public static final String STR_SAMPLE_BYE = "bye";
	
	// Test actions constants definition
	public static final int TEST_RESPONSEISCODE = 0;
	public static final int TEST_RESPONSEIS1XX = 1;
	public static final int TEST_RESPONSEIS2XX = 2;
	public static final int TEST_RESPONSEIS3XX = 3;
	public static final int TEST_RESPONSEIS4XX = 4;
	public static final int TEST_RESPONSEIS5XX = 5;
	public static final int TEST_RESPONSEIS6XX = 6;
	public static final int TEST_REQUESTISINVITE = 7;
	public static final int TEST_REQUESTISACK = 8;
	public static final int TEST_REQUESTISCANCEL = 9;
	public static final int TEST_REQUESTISBYE = 10;
	public static final int TEST_REQUESTISMESSAGE = 11;
	public static final String STR_TEST_RESPONSEISCODE = "responseIsCode";
	public static final String STR_TEST_PARAM_RESPONSEISCODE = "responseCode";
	public static final String STR_TEST_RESPONSEIS1XX = "responseIs1xx";
	public static final String STR_TEST_RESPONSEIS2XX = "responseIs2xx";
	public static final String STR_TEST_RESPONSEIS3XX = "responseIs3xx";
	public static final String STR_TEST_RESPONSEIS4XX = "responseIs4xx";
	public static final String STR_TEST_RESPONSEIS5XX = "responseIs5xx";
	public static final String STR_TEST_RESPONSEIS6XX = "responseIs6xx";
	public static final String STR_TEST_REQUESTISINVITE = "requestIsINVITE";
	public static final String STR_TEST_REQUESTISACK = "requestIsACK";
	public static final String STR_TEST_REQUESTISCANCEL = "requestIsCANCEL";
	public static final String STR_TEST_REQUESTISBYE = "requestIsBYE";
	public static final String STR_TEST_REQUESTISMESSAGE = "requestIsMESSAGE";
	
	
	// Control actions constants definition
	public static final int CONTROL_REGISTER = 0;
	public static final int CONTROL_RESPOND = 1;
	public static final int CONTROL_INVITE = 5;
	public static final int CONTROL_ACK = 6;
	public static final int CONTROL_WAITREQUEST = 7;
	
	public static final String STR_CONTROL_PARAM_CODETORESPOND = "codeToRespond";
	
	public static final String STR_CONTROL_REGISTER = "register";
	public static final String STR_CONTROL_RESPOND = "respond";
	public static final String STR_CONTROL_INVITE = "invite";
	public static final String STR_CONTROL_ACK = "ack";
	public static final String STR_CONTROL_WAITREQUEST = "waitRequest";
	
	
}
